diff --git a/assignment/assignment.cpp b/assignment/assignment.cpp
index a93c310ea0c1881364fa3cd33923ba3bf8a9dab2..b190c00207534be38c38f5b13c0b910f7e7838a7 100644
--- a/assignment/assignment.cpp
+++ b/assignment/assignment.cpp
@@ -42,11 +42,11 @@
 
 using namespace std;
 
-const int width = 640;
-// Defines the variable 'width' as a constant integer of 640.
+const int width = 1024;
+// Defines the variable 'width' as a constant integer of 1024.
 
-const int height = 480;
-// Defines the variable 'height' as a constant integer of 480.
+const int height = 640;
+// Defines the variable 'height' as a constant integer of 640.
 
 class MyApp: public uwe::App {
     // Creates public class referred to as 'MyApp'